@@ -26,7 +26,6 @@
 #include <QIcon>
 #include <akonadi/private/instance_p.h>
 #include <akonadi/private/dbus_p.h>
-#include <akonadi/private/xdgbasedirs_p.h>
 
 #include <QApplication>
 #include <QDBusConnection>
@@ -96,15 +95,6 @@ void InstanceSelector::slotAccept()
     }
     QDialog::accept();
 
-    if (!m_instance.isEmpty()) {
-        QDBusInterface serverIface(QStringLiteral("org.freedesktop.Akonadi.%1").arg(m_instance),
-                                   QStringLiteral("/Server"),
-                                   QStringLiteral("org.freedesktop.Akonadi.Server"),
-                                   QDBusConnection::sessionBus());
-        const QDBusReply<QString> serverPath = serverIface.call(QStringLiteral("serverPath"));
-        Akonadi::XdgBaseDirs::overrideConfigPath(serverPath);
-    }
-
     qputenv("AKONADI_INSTANCE", m_instance.toUtf8());
     Akonadi::Instance::setIdentifier(m_instance);
     MainWindow *mWindow = new MainWindow;
